@@ -1,15 +1,31 @@
 use crate::nalgebra_2d;
-use approx::ulps_eq;
-#[cfg(feature = "impl-rayon")]
+use approx::{ulps_eq, AbsDiffEq, RelativeEq, UlpsEq};
+#[cfg(feature = "rayon")]
 use rayon::prelude::*;
 use std::cmp::Ordering;
 use std::marker::PhantomData;
 
-pub struct ConvexHull<T: nalgebra::RealField + Sync> {
+pub struct ConvexHull<T>
+where
+    T: nalgebra::RealField
+        + Sync
+        + AbsDiffEq<Epsilon = T>
+        + UlpsEq<Epsilon = T>
+        + RelativeEq<Epsilon = T>
+        + num_traits::cast::NumCast,
+{
     pd: PhantomData<T>,
 }
 
-impl<T: nalgebra::RealField + Sync> ConvexHull<T> {
+impl<T> ConvexHull<T>
+where
+    T: nalgebra::RealField
+        + Sync
+        + AbsDiffEq<Epsilon = T>
+        + UlpsEq<Epsilon = T>
+        + RelativeEq<Epsilon = T>
+        + num_traits::cast::NumCast,
+{
     /// finds the point with lowest x
     fn find_lowest_x(linestring: &[nalgebra::Point2<T>]) -> (usize, nalgebra::Point2<T>) {
         let mut lowest = linestring[0];
@@ -83,12 +99,12 @@ impl<T: nalgebra::RealField + Sync> ConvexHull<T> {
         a: &nalgebra::Point2<T>,
         b: &nalgebra::Point2<T>,
         c: &nalgebra::Point2<T>,
-        epsilon: T::Epsilon,
+        epsilon: <T as AbsDiffEq>::Epsilon,
         max_ulps: u32,
     ) -> bool {
         let t1 = (b.x - a.x) * (c.y - a.y);
         let t2 = (b.y - a.y) * (c.x - a.x);
-        if t1.ulps_eq(&t2, epsilon, max_ulps) {
+        if UlpsEq::ulps_eq(&t1, &t2, epsilon, max_ulps) {
             true
         } else {
             t1 >= t2
@@ -305,6 +321,8 @@ impl<T: nalgebra::RealField + Sync> ConvexHull<T> {
     /// # use linestring::nalgebra_2d;
     /// # use linestring::nalgebra_2d::convex_hull;
     /// # use rand::{Rng, SeedableRng};
+    /// # use approx::AbsDiffEq;
+    /// # use approx::UlpsEq;
     ///
     /// let mut rng = rand_chacha::ChaCha8Rng::seed_from_u64(38);
     /// let mut points = Vec::<nalgebra::Point2<f32>>::new();
@@ -325,11 +343,16 @@ impl<T: nalgebra::RealField + Sync> ConvexHull<T> {
     /// let b = nalgebra_2d::LineString2::<f32>::default().with_points(points);
     /// let b = convex_hull::ConvexHull::graham_scan(b.points().iter());
     ///
-    /// assert!(convex_hull::ConvexHull::contains(&a, &b));
-    /// assert!(!convex_hull::ConvexHull::contains(&b, &a));
+    /// assert!(convex_hull::ConvexHull::contains(&a, &b, f32::default_epsilon(), f32::default_max_ulps()));
+    /// assert!(!convex_hull::ConvexHull::contains(&b, &a, f32::default_epsilon(), f32::default_max_ulps()));
     ///```
-    #[cfg(not(feature = "impl-rayon"))]
-    pub fn contains(a: &nalgebra_2d::LineString2<T>, b: &nalgebra_2d::LineString2<T>) -> bool {
+    #[cfg(not(feature = "rayon"))]
+    pub fn contains(
+        a: &nalgebra_2d::LineString2<T>,
+        b: &nalgebra_2d::LineString2<T>,
+        epsilon: <T as AbsDiffEq>::Epsilon,
+        max_ulps: u32,
+    ) -> bool {
         if a.len() <= 1 {
             return false;
         }
@@ -343,7 +366,9 @@ impl<T: nalgebra::RealField + Sync> ConvexHull<T> {
             for l in a.as_lines().iter().skip(step1).step_by(4) {
                 for step2 in 0..4 {
                     for p in b.points.iter().skip(step2).step_by(4) {
-                        if !Self::is_point_left_allow_collinear(&l.start, &l.end, p) {
+                        if !Self::is_point_left_allow_collinear_ulps(
+                            &l.start, &l.end, p, epsilon, max_ulps,
+                        ) {
                             //println!("The point {:?} is not left of {:?}", p, l);
                             return false;
                         }
@@ -384,11 +409,11 @@ impl<T: nalgebra::RealField + Sync> ConvexHull<T> {
     /// assert!(convex_hull::ConvexHull::contains(&a, &b, f32::default_epsilon(), f32::default_max_ulps()));
     /// assert!(!convex_hull::ConvexHull::contains(&b, &a, f32::default_epsilon(), f32::default_max_ulps()));
     ///```
-    #[cfg(feature = "impl-rayon")]
+    #[cfg(feature = "rayon")]
     pub fn contains(
         a: &nalgebra_2d::LineString2<T>,
         b: &nalgebra_2d::LineString2<T>,
-        epsilon: T::Epsilon,
+        epsilon: <T as AbsDiffEq>::Epsilon,
         max_ulps: u32,
     ) -> bool {
         if a.len() <= 1 {
@@ -435,7 +460,7 @@ impl<T: nalgebra::RealField + Sync> ConvexHull<T> {
     /// assert!(!convex_hull::ConvexHull::contains_point_exclusive(&hull, &[10.0,9.99999].into()));
     ///
     ///```
-    #[cfg(feature = "impl-rayon")]
+    #[cfg(feature = "rayon")]
     pub fn contains_point_exclusive(
         a: &nalgebra_2d::LineString2<T>,
         p: &nalgebra::Point2<T>,
@@ -473,7 +498,7 @@ impl<T: nalgebra::RealField + Sync> ConvexHull<T> {
     /// assert!(convex_hull::ConvexHull::contains_point_inclusive(&hull, &[9.999,5.0].into()));
     /// assert!(convex_hull::ConvexHull::contains_point_inclusive(&hull, &[10.0,5.0].into()));
     ///```
-    #[cfg(feature = "impl-rayon")]
+    #[cfg(feature = "rayon")]
     pub fn contains_point_inclusive(
         a: &nalgebra_2d::LineString2<T>,
         p: &nalgebra::Point2<T>,
