@@ -850,7 +850,7 @@ where
                 {
                     // emulate pop_first
                     if let Some((first_key, _)) = site_events.iter().next() {
-                        let first_key = first_key.clone();
+                        let first_key = *first_key;
                         let v = site_events.remove(&first_key).ok_or_else(|| {
                             LinestringError::InternalError(format!(
                                 "Found a key to pop but could not remove the value. {}:{}",
